@@ -3,7 +3,7 @@ package HTTP::Request::Common;
 use strict;
 use warnings;
 
-our $VERSION = '6.34';
+our $VERSION = '6.36';
 
 our $DYNAMIC_FILE_UPLOAD ||= 0;  # make it defined (don't know why)
 
@@ -314,17 +314,17 @@ HTTP::Request::Common - Construct common HTTP::Request objects
 
 =head1 VERSION
 
-version 6.34
+version 6.36
 
 =head1 SYNOPSIS
 
   use HTTP::Request::Common;
   $ua = LWP::UserAgent->new;
   $ua->request(GET 'http://www.sn.no/');
-  $ua->request(POST 'http://somewhere/foo', [foo => bar, bar => foo]);
-  $ua->request(PATCH 'http://somewhere/foo', [foo => bar, bar => foo]);
-  $ua->request(PUT 'http://somewhere/foo', [foo => bar, bar => foo]);
-  $ua->request(OPTIONS 'http://somewhere/foo', [foo => bar, bar => foo]);
+  $ua->request(POST 'http://somewhere/foo', foo => bar, bar => foo);
+  $ua->request(PATCH 'http://somewhere/foo', foo => bar, bar => foo);
+  $ua->request(PUT 'http://somewhere/foo', foo => bar, bar => foo);
+  $ua->request(OPTIONS 'http://somewhere/foo', foo => bar, bar => foo);
 
 =head1 DESCRIPTION
 
